@@ -4,7 +4,7 @@ Main interface for shield service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_shield import (
         Client,
         ListAttacksPaginator,
@@ -12,10 +12,8 @@ Usage::
         ShieldClient,
     )
 
-    session = boto3.Session()
-
-    client: ShieldClient = boto3.client("shield")
-    session_client: ShieldClient = session.client("shield")
+    session = Session()
+    client: ShieldClient = session.client("shield")
 
     list_attacks_paginator: ListAttacksPaginator = client.get_paginator("list_attacks")
     list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
