@@ -6,9 +6,9 @@ Type annotations for shield service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_shield.type_defs import ApplicationLayerAutomaticResponseConfigurationTypeDef
+    from mypy_boto3_shield.type_defs import ResponseActionTypeDef
 
-    data: ApplicationLayerAutomaticResponseConfigurationTypeDef = {...}
+    data: ResponseActionTypeDef = {...}
     ```
 """
 import sys
@@ -36,84 +36,87 @@ else:
 
 
 __all__ = (
-    "ApplicationLayerAutomaticResponseConfigurationTypeDef",
+    "ResponseActionTypeDef",
     "AssociateDRTLogBucketRequestRequestTypeDef",
     "AssociateDRTRoleRequestRequestTypeDef",
     "AssociateHealthCheckRequestRequestTypeDef",
-    "AssociateProactiveEngagementDetailsRequestRequestTypeDef",
-    "AttackDetailTypeDef",
-    "AttackPropertyTypeDef",
-    "AttackStatisticsDataItemTypeDef",
-    "AttackSummaryTypeDef",
+    "EmergencyContactTypeDef",
+    "MitigationTypeDef",
+    "SummarizedCounterTypeDef",
+    "ContributorTypeDef",
     "AttackVectorDescriptionTypeDef",
     "AttackVolumeStatisticsTypeDef",
-    "AttackVolumeTypeDef",
-    "ContributorTypeDef",
-    "CreateProtectionGroupRequestRequestTypeDef",
-    "CreateProtectionRequestRequestTypeDef",
-    "CreateProtectionResponseTypeDef",
+    "TagTypeDef",
+    "ResponseMetadataTypeDef",
     "DeleteProtectionGroupRequestRequestTypeDef",
     "DeleteProtectionRequestRequestTypeDef",
     "DescribeAttackRequestRequestTypeDef",
-    "DescribeAttackResponseTypeDef",
-    "DescribeAttackStatisticsResponseTypeDef",
-    "DescribeDRTAccessResponseTypeDef",
-    "DescribeEmergencyContactSettingsResponseTypeDef",
+    "TimeRangeTypeDef",
     "DescribeProtectionGroupRequestRequestTypeDef",
-    "DescribeProtectionGroupResponseTypeDef",
+    "ProtectionGroupTypeDef",
     "DescribeProtectionRequestRequestTypeDef",
-    "DescribeProtectionResponseTypeDef",
-    "DescribeSubscriptionResponseTypeDef",
     "DisableApplicationLayerAutomaticResponseRequestRequestTypeDef",
     "DisassociateDRTLogBucketRequestRequestTypeDef",
     "DisassociateHealthCheckRequestRequestTypeDef",
-    "EmergencyContactTypeDef",
-    "EnableApplicationLayerAutomaticResponseRequestRequestTypeDef",
-    "GetSubscriptionStateResponseTypeDef",
+    "InclusionProtectionFiltersTypeDef",
+    "InclusionProtectionGroupFiltersTypeDef",
     "LimitTypeDef",
-    "ListAttacksRequestListAttacksPaginateTypeDef",
-    "ListAttacksRequestRequestTypeDef",
-    "ListAttacksResponseTypeDef",
-    "ListProtectionGroupsRequestRequestTypeDef",
-    "ListProtectionGroupsResponseTypeDef",
-    "ListProtectionsRequestListProtectionsPaginateTypeDef",
-    "ListProtectionsRequestRequestTypeDef",
-    "ListProtectionsResponseTypeDef",
-    "ListResourcesInProtectionGroupRequestRequestTypeDef",
-    "ListResourcesInProtectionGroupResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "MitigationTypeDef",
     "PaginatorConfigTypeDef",
+    "ListResourcesInProtectionGroupRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ProtectionGroupArbitraryPatternLimitsTypeDef",
-    "ProtectionGroupLimitsTypeDef",
-    "ProtectionGroupPatternTypeLimitsTypeDef",
-    "ProtectionGroupTypeDef",
-    "ProtectionLimitsTypeDef",
-    "ProtectionTypeDef",
-    "ResponseActionTypeDef",
-    "ResponseMetadataTypeDef",
-    "SubResourceSummaryTypeDef",
-    "SubscriptionLimitsTypeDef",
-    "SubscriptionTypeDef",
-    "SummarizedAttackVectorTypeDef",
-    "SummarizedCounterTypeDef",
-    "TagResourceRequestRequestTypeDef",
-    "TagTypeDef",
-    "TimeRangeTypeDef",
     "UntagResourceRequestRequestTypeDef",
-    "UpdateApplicationLayerAutomaticResponseRequestRequestTypeDef",
-    "UpdateEmergencyContactSettingsRequestRequestTypeDef",
     "UpdateProtectionGroupRequestRequestTypeDef",
     "UpdateSubscriptionRequestRequestTypeDef",
+    "ApplicationLayerAutomaticResponseConfigurationTypeDef",
+    "EnableApplicationLayerAutomaticResponseRequestRequestTypeDef",
+    "UpdateApplicationLayerAutomaticResponseRequestRequestTypeDef",
+    "AssociateProactiveEngagementDetailsRequestRequestTypeDef",
+    "UpdateEmergencyContactSettingsRequestRequestTypeDef",
+    "SummarizedAttackVectorTypeDef",
+    "AttackPropertyTypeDef",
+    "AttackSummaryTypeDef",
+    "AttackVolumeTypeDef",
+    "CreateProtectionGroupRequestRequestTypeDef",
+    "CreateProtectionRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "CreateProtectionResponseTypeDef",
+    "DescribeDRTAccessResponseTypeDef",
+    "DescribeEmergencyContactSettingsResponseTypeDef",
+    "GetSubscriptionStateResponseTypeDef",
+    "ListResourcesInProtectionGroupResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "ListAttacksRequestRequestTypeDef",
+    "DescribeProtectionGroupResponseTypeDef",
+    "ListProtectionGroupsResponseTypeDef",
+    "ListProtectionsRequestRequestTypeDef",
+    "ListProtectionGroupsRequestRequestTypeDef",
+    "ProtectionLimitsTypeDef",
+    "ListAttacksRequestListAttacksPaginateTypeDef",
+    "ListProtectionsRequestListProtectionsPaginateTypeDef",
+    "ProtectionGroupPatternTypeLimitsTypeDef",
+    "ProtectionTypeDef",
+    "SubResourceSummaryTypeDef",
+    "ListAttacksResponseTypeDef",
+    "AttackStatisticsDataItemTypeDef",
+    "ProtectionGroupLimitsTypeDef",
+    "DescribeProtectionResponseTypeDef",
+    "ListProtectionsResponseTypeDef",
+    "AttackDetailTypeDef",
+    "DescribeAttackStatisticsResponseTypeDef",
+    "SubscriptionLimitsTypeDef",
+    "DescribeAttackResponseTypeDef",
+    "SubscriptionTypeDef",
+    "DescribeSubscriptionResponseTypeDef",
 )
 
-ApplicationLayerAutomaticResponseConfigurationTypeDef = TypedDict(
-    "ApplicationLayerAutomaticResponseConfigurationTypeDef",
+ResponseActionTypeDef = TypedDict(
+    "ResponseActionTypeDef",
     {
-        "Status": ApplicationLayerAutomaticResponseStatusType,
-        "Action": "ResponseActionTypeDef",
+        "Block": Dict[str, Any],
+        "Count": Dict[str, Any],
     },
+    total=False,
 )
 
 AssociateDRTLogBucketRequestRequestTypeDef = TypedDict(
@@ -138,279 +141,6 @@ AssociateHealthCheckRequestRequestTypeDef = TypedDict(
     },
 )
 
-AssociateProactiveEngagementDetailsRequestRequestTypeDef = TypedDict(
-    "AssociateProactiveEngagementDetailsRequestRequestTypeDef",
-    {
-        "EmergencyContactList": Sequence["EmergencyContactTypeDef"],
-    },
-)
-
-AttackDetailTypeDef = TypedDict(
-    "AttackDetailTypeDef",
-    {
-        "AttackId": str,
-        "ResourceArn": str,
-        "SubResources": List["SubResourceSummaryTypeDef"],
-        "StartTime": datetime,
-        "EndTime": datetime,
-        "AttackCounters": List["SummarizedCounterTypeDef"],
-        "AttackProperties": List["AttackPropertyTypeDef"],
-        "Mitigations": List["MitigationTypeDef"],
-    },
-    total=False,
-)
-
-AttackPropertyTypeDef = TypedDict(
-    "AttackPropertyTypeDef",
-    {
-        "AttackLayer": AttackLayerType,
-        "AttackPropertyIdentifier": AttackPropertyIdentifierType,
-        "TopContributors": List["ContributorTypeDef"],
-        "Unit": UnitType,
-        "Total": int,
-    },
-    total=False,
-)
-
-_RequiredAttackStatisticsDataItemTypeDef = TypedDict(
-    "_RequiredAttackStatisticsDataItemTypeDef",
-    {
-        "AttackCount": int,
-    },
-)
-_OptionalAttackStatisticsDataItemTypeDef = TypedDict(
-    "_OptionalAttackStatisticsDataItemTypeDef",
-    {
-        "AttackVolume": "AttackVolumeTypeDef",
-    },
-    total=False,
-)
-
-
-class AttackStatisticsDataItemTypeDef(
-    _RequiredAttackStatisticsDataItemTypeDef, _OptionalAttackStatisticsDataItemTypeDef
-):
-    pass
-
-
-AttackSummaryTypeDef = TypedDict(
-    "AttackSummaryTypeDef",
-    {
-        "AttackId": str,
-        "ResourceArn": str,
-        "StartTime": datetime,
-        "EndTime": datetime,
-        "AttackVectors": List["AttackVectorDescriptionTypeDef"],
-    },
-    total=False,
-)
-
-AttackVectorDescriptionTypeDef = TypedDict(
-    "AttackVectorDescriptionTypeDef",
-    {
-        "VectorType": str,
-    },
-)
-
-AttackVolumeStatisticsTypeDef = TypedDict(
-    "AttackVolumeStatisticsTypeDef",
-    {
-        "Max": float,
-    },
-)
-
-AttackVolumeTypeDef = TypedDict(
-    "AttackVolumeTypeDef",
-    {
-        "BitsPerSecond": "AttackVolumeStatisticsTypeDef",
-        "PacketsPerSecond": "AttackVolumeStatisticsTypeDef",
-        "RequestsPerSecond": "AttackVolumeStatisticsTypeDef",
-    },
-    total=False,
-)
-
-ContributorTypeDef = TypedDict(
-    "ContributorTypeDef",
-    {
-        "Name": str,
-        "Value": int,
-    },
-    total=False,
-)
-
-_RequiredCreateProtectionGroupRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateProtectionGroupRequestRequestTypeDef",
-    {
-        "ProtectionGroupId": str,
-        "Aggregation": ProtectionGroupAggregationType,
-        "Pattern": ProtectionGroupPatternType,
-    },
-)
-_OptionalCreateProtectionGroupRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateProtectionGroupRequestRequestTypeDef",
-    {
-        "ResourceType": ProtectedResourceTypeType,
-        "Members": Sequence[str],
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateProtectionGroupRequestRequestTypeDef(
-    _RequiredCreateProtectionGroupRequestRequestTypeDef,
-    _OptionalCreateProtectionGroupRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredCreateProtectionRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateProtectionRequestRequestTypeDef",
-    {
-        "Name": str,
-        "ResourceArn": str,
-    },
-)
-_OptionalCreateProtectionRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateProtectionRequestRequestTypeDef",
-    {
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateProtectionRequestRequestTypeDef(
-    _RequiredCreateProtectionRequestRequestTypeDef, _OptionalCreateProtectionRequestRequestTypeDef
-):
-    pass
-
-
-CreateProtectionResponseTypeDef = TypedDict(
-    "CreateProtectionResponseTypeDef",
-    {
-        "ProtectionId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DeleteProtectionGroupRequestRequestTypeDef = TypedDict(
-    "DeleteProtectionGroupRequestRequestTypeDef",
-    {
-        "ProtectionGroupId": str,
-    },
-)
-
-DeleteProtectionRequestRequestTypeDef = TypedDict(
-    "DeleteProtectionRequestRequestTypeDef",
-    {
-        "ProtectionId": str,
-    },
-)
-
-DescribeAttackRequestRequestTypeDef = TypedDict(
-    "DescribeAttackRequestRequestTypeDef",
-    {
-        "AttackId": str,
-    },
-)
-
-DescribeAttackResponseTypeDef = TypedDict(
-    "DescribeAttackResponseTypeDef",
-    {
-        "Attack": "AttackDetailTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeAttackStatisticsResponseTypeDef = TypedDict(
-    "DescribeAttackStatisticsResponseTypeDef",
-    {
-        "TimeRange": "TimeRangeTypeDef",
-        "DataItems": List["AttackStatisticsDataItemTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeDRTAccessResponseTypeDef = TypedDict(
-    "DescribeDRTAccessResponseTypeDef",
-    {
-        "RoleArn": str,
-        "LogBucketList": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeEmergencyContactSettingsResponseTypeDef = TypedDict(
-    "DescribeEmergencyContactSettingsResponseTypeDef",
-    {
-        "EmergencyContactList": List["EmergencyContactTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeProtectionGroupRequestRequestTypeDef = TypedDict(
-    "DescribeProtectionGroupRequestRequestTypeDef",
-    {
-        "ProtectionGroupId": str,
-    },
-)
-
-DescribeProtectionGroupResponseTypeDef = TypedDict(
-    "DescribeProtectionGroupResponseTypeDef",
-    {
-        "ProtectionGroup": "ProtectionGroupTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeProtectionRequestRequestTypeDef = TypedDict(
-    "DescribeProtectionRequestRequestTypeDef",
-    {
-        "ProtectionId": str,
-        "ResourceArn": str,
-    },
-    total=False,
-)
-
-DescribeProtectionResponseTypeDef = TypedDict(
-    "DescribeProtectionResponseTypeDef",
-    {
-        "Protection": "ProtectionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeSubscriptionResponseTypeDef = TypedDict(
-    "DescribeSubscriptionResponseTypeDef",
-    {
-        "Subscription": "SubscriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DisableApplicationLayerAutomaticResponseRequestRequestTypeDef = TypedDict(
-    "DisableApplicationLayerAutomaticResponseRequestRequestTypeDef",
-    {
-        "ResourceArn": str,
-    },
-)
-
-DisassociateDRTLogBucketRequestRequestTypeDef = TypedDict(
-    "DisassociateDRTLogBucketRequestRequestTypeDef",
-    {
-        "LogBucket": str,
-    },
-)
-
-DisassociateHealthCheckRequestRequestTypeDef = TypedDict(
-    "DisassociateHealthCheckRequestRequestTypeDef",
-    {
-        "ProtectionId": str,
-        "HealthCheckArn": str,
-    },
-)
-
 _RequiredEmergencyContactTypeDef = TypedDict(
     "_RequiredEmergencyContactTypeDef",
     {
@@ -431,154 +161,6 @@ class EmergencyContactTypeDef(_RequiredEmergencyContactTypeDef, _OptionalEmergen
     pass
 
 
-EnableApplicationLayerAutomaticResponseRequestRequestTypeDef = TypedDict(
-    "EnableApplicationLayerAutomaticResponseRequestRequestTypeDef",
-    {
-        "ResourceArn": str,
-        "Action": "ResponseActionTypeDef",
-    },
-)
-
-GetSubscriptionStateResponseTypeDef = TypedDict(
-    "GetSubscriptionStateResponseTypeDef",
-    {
-        "SubscriptionState": SubscriptionStateType,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-LimitTypeDef = TypedDict(
-    "LimitTypeDef",
-    {
-        "Type": str,
-        "Max": int,
-    },
-    total=False,
-)
-
-ListAttacksRequestListAttacksPaginateTypeDef = TypedDict(
-    "ListAttacksRequestListAttacksPaginateTypeDef",
-    {
-        "ResourceArns": Sequence[str],
-        "StartTime": "TimeRangeTypeDef",
-        "EndTime": "TimeRangeTypeDef",
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-ListAttacksRequestRequestTypeDef = TypedDict(
-    "ListAttacksRequestRequestTypeDef",
-    {
-        "ResourceArns": Sequence[str],
-        "StartTime": "TimeRangeTypeDef",
-        "EndTime": "TimeRangeTypeDef",
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-ListAttacksResponseTypeDef = TypedDict(
-    "ListAttacksResponseTypeDef",
-    {
-        "AttackSummaries": List["AttackSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListProtectionGroupsRequestRequestTypeDef = TypedDict(
-    "ListProtectionGroupsRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-ListProtectionGroupsResponseTypeDef = TypedDict(
-    "ListProtectionGroupsResponseTypeDef",
-    {
-        "ProtectionGroups": List["ProtectionGroupTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListProtectionsRequestListProtectionsPaginateTypeDef = TypedDict(
-    "ListProtectionsRequestListProtectionsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-ListProtectionsRequestRequestTypeDef = TypedDict(
-    "ListProtectionsRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-ListProtectionsResponseTypeDef = TypedDict(
-    "ListProtectionsResponseTypeDef",
-    {
-        "Protections": List["ProtectionTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListResourcesInProtectionGroupRequestRequestTypeDef = TypedDict(
-    "_RequiredListResourcesInProtectionGroupRequestRequestTypeDef",
-    {
-        "ProtectionGroupId": str,
-    },
-)
-_OptionalListResourcesInProtectionGroupRequestRequestTypeDef = TypedDict(
-    "_OptionalListResourcesInProtectionGroupRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListResourcesInProtectionGroupRequestRequestTypeDef(
-    _RequiredListResourcesInProtectionGroupRequestRequestTypeDef,
-    _OptionalListResourcesInProtectionGroupRequestRequestTypeDef,
-):
-    pass
-
-
-ListResourcesInProtectionGroupResponseTypeDef = TypedDict(
-    "ListResourcesInProtectionGroupResponseTypeDef",
-    {
-        "ResourceArns": List[str],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
-    {
-        "ResourceARN": str,
-    },
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": List["TagTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 MitigationTypeDef = TypedDict(
     "MitigationTypeDef",
     {
@@ -587,35 +169,96 @@ MitigationTypeDef = TypedDict(
     total=False,
 )
 
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
+SummarizedCounterTypeDef = TypedDict(
+    "SummarizedCounterTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "Name": str,
+        "Max": float,
+        "Average": float,
+        "Sum": float,
+        "N": int,
+        "Unit": str,
     },
     total=False,
 )
 
-ProtectionGroupArbitraryPatternLimitsTypeDef = TypedDict(
-    "ProtectionGroupArbitraryPatternLimitsTypeDef",
+ContributorTypeDef = TypedDict(
+    "ContributorTypeDef",
     {
-        "MaxMembers": int,
+        "Name": str,
+        "Value": int,
+    },
+    total=False,
+)
+
+AttackVectorDescriptionTypeDef = TypedDict(
+    "AttackVectorDescriptionTypeDef",
+    {
+        "VectorType": str,
     },
 )
 
-ProtectionGroupLimitsTypeDef = TypedDict(
-    "ProtectionGroupLimitsTypeDef",
+AttackVolumeStatisticsTypeDef = TypedDict(
+    "AttackVolumeStatisticsTypeDef",
     {
-        "MaxProtectionGroups": int,
-        "PatternTypeLimits": "ProtectionGroupPatternTypeLimitsTypeDef",
+        "Max": float,
     },
 )
 
-ProtectionGroupPatternTypeLimitsTypeDef = TypedDict(
-    "ProtectionGroupPatternTypeLimitsTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
-        "ArbitraryPatternLimits": "ProtectionGroupArbitraryPatternLimitsTypeDef",
+        "Key": str,
+        "Value": str,
+    },
+    total=False,
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
+DeleteProtectionGroupRequestRequestTypeDef = TypedDict(
+    "DeleteProtectionGroupRequestRequestTypeDef",
+    {
+        "ProtectionGroupId": str,
+    },
+)
+
+DeleteProtectionRequestRequestTypeDef = TypedDict(
+    "DeleteProtectionRequestRequestTypeDef",
+    {
+        "ProtectionId": str,
+    },
+)
+
+DescribeAttackRequestRequestTypeDef = TypedDict(
+    "DescribeAttackRequestRequestTypeDef",
+    {
+        "AttackId": str,
+    },
+)
+
+TimeRangeTypeDef = TypedDict(
+    "TimeRangeTypeDef",
+    {
+        "FromInclusive": datetime,
+        "ToExclusive": datetime,
+    },
+    total=False,
+)
+
+DescribeProtectionGroupRequestRequestTypeDef = TypedDict(
+    "DescribeProtectionGroupRequestRequestTypeDef",
+    {
+        "ProtectionGroupId": str,
     },
 )
 
@@ -642,150 +285,112 @@ class ProtectionGroupTypeDef(_RequiredProtectionGroupTypeDef, _OptionalProtectio
     pass
 
 
-ProtectionLimitsTypeDef = TypedDict(
-    "ProtectionLimitsTypeDef",
+DescribeProtectionRequestRequestTypeDef = TypedDict(
+    "DescribeProtectionRequestRequestTypeDef",
     {
-        "ProtectedResourceTypeLimits": List["LimitTypeDef"],
-    },
-)
-
-ProtectionTypeDef = TypedDict(
-    "ProtectionTypeDef",
-    {
-        "Id": str,
-        "Name": str,
+        "ProtectionId": str,
         "ResourceArn": str,
-        "HealthCheckIds": List[str],
-        "ProtectionArn": str,
-        "ApplicationLayerAutomaticResponseConfiguration": (
-            "ApplicationLayerAutomaticResponseConfigurationTypeDef"
-        ),
     },
     total=False,
 )
 
-ResponseActionTypeDef = TypedDict(
-    "ResponseActionTypeDef",
+DisableApplicationLayerAutomaticResponseRequestRequestTypeDef = TypedDict(
+    "DisableApplicationLayerAutomaticResponseRequestRequestTypeDef",
     {
-        "Block": Dict[str, Any],
-        "Count": Dict[str, Any],
+        "ResourceArn": str,
+    },
+)
+
+DisassociateDRTLogBucketRequestRequestTypeDef = TypedDict(
+    "DisassociateDRTLogBucketRequestRequestTypeDef",
+    {
+        "LogBucket": str,
+    },
+)
+
+DisassociateHealthCheckRequestRequestTypeDef = TypedDict(
+    "DisassociateHealthCheckRequestRequestTypeDef",
+    {
+        "ProtectionId": str,
+        "HealthCheckArn": str,
+    },
+)
+
+InclusionProtectionFiltersTypeDef = TypedDict(
+    "InclusionProtectionFiltersTypeDef",
+    {
+        "ResourceArns": Sequence[str],
+        "ProtectionNames": Sequence[str],
+        "ResourceTypes": Sequence[ProtectedResourceTypeType],
     },
     total=False,
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+InclusionProtectionGroupFiltersTypeDef = TypedDict(
+    "InclusionProtectionGroupFiltersTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-SubResourceSummaryTypeDef = TypedDict(
-    "SubResourceSummaryTypeDef",
-    {
-        "Type": SubResourceTypeType,
-        "Id": str,
-        "AttackVectors": List["SummarizedAttackVectorTypeDef"],
-        "Counters": List["SummarizedCounterTypeDef"],
+        "ProtectionGroupIds": Sequence[str],
+        "Patterns": Sequence[ProtectionGroupPatternType],
+        "ResourceTypes": Sequence[ProtectedResourceTypeType],
+        "Aggregations": Sequence[ProtectionGroupAggregationType],
     },
     total=False,
 )
 
-SubscriptionLimitsTypeDef = TypedDict(
-    "SubscriptionLimitsTypeDef",
+LimitTypeDef = TypedDict(
+    "LimitTypeDef",
     {
-        "ProtectionLimits": "ProtectionLimitsTypeDef",
-        "ProtectionGroupLimits": "ProtectionGroupLimitsTypeDef",
+        "Type": str,
+        "Max": int,
     },
+    total=False,
 )
 
-_RequiredSubscriptionTypeDef = TypedDict(
-    "_RequiredSubscriptionTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "SubscriptionLimits": "SubscriptionLimitsTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
+_RequiredListResourcesInProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredListResourcesInProtectionGroupRequestRequestTypeDef",
+    {
+        "ProtectionGroupId": str,
     },
 )
-_OptionalSubscriptionTypeDef = TypedDict(
-    "_OptionalSubscriptionTypeDef",
+_OptionalListResourcesInProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalListResourcesInProtectionGroupRequestRequestTypeDef",
     {
-        "StartTime": datetime,
-        "EndTime": datetime,
-        "TimeCommitmentInSeconds": int,
-        "AutoRenew": AutoRenewType,
-        "Limits": List["LimitTypeDef"],
-        "ProactiveEngagementStatus": ProactiveEngagementStatusType,
-        "SubscriptionArn": str,
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
 
-class SubscriptionTypeDef(_RequiredSubscriptionTypeDef, _OptionalSubscriptionTypeDef):
-    pass
-
-
-_RequiredSummarizedAttackVectorTypeDef = TypedDict(
-    "_RequiredSummarizedAttackVectorTypeDef",
-    {
-        "VectorType": str,
-    },
-)
-_OptionalSummarizedAttackVectorTypeDef = TypedDict(
-    "_OptionalSummarizedAttackVectorTypeDef",
-    {
-        "VectorCounters": List["SummarizedCounterTypeDef"],
-    },
-    total=False,
-)
-
-
-class SummarizedAttackVectorTypeDef(
-    _RequiredSummarizedAttackVectorTypeDef, _OptionalSummarizedAttackVectorTypeDef
+class ListResourcesInProtectionGroupRequestRequestTypeDef(
+    _RequiredListResourcesInProtectionGroupRequestRequestTypeDef,
+    _OptionalListResourcesInProtectionGroupRequestRequestTypeDef,
 ):
     pass
 
 
-SummarizedCounterTypeDef = TypedDict(
-    "SummarizedCounterTypeDef",
-    {
-        "Name": str,
-        "Max": float,
-        "Average": float,
-        "Sum": float,
-        "N": int,
-        "Unit": str,
-    },
-    total=False,
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": Sequence["TagTypeDef"],
     },
 )
 
-TagTypeDef = TypedDict(
-    "TagTypeDef",
+ProtectionGroupArbitraryPatternLimitsTypeDef = TypedDict(
+    "ProtectionGroupArbitraryPatternLimitsTypeDef",
     {
-        "Key": str,
-        "Value": str,
+        "MaxMembers": int,
     },
-    total=False,
-)
-
-TimeRangeTypeDef = TypedDict(
-    "TimeRangeTypeDef",
-    {
-        "FromInclusive": datetime,
-        "ToExclusive": datetime,
-    },
-    total=False,
 )
 
 UntagResourceRequestRequestTypeDef = TypedDict(
@@ -796,22 +401,6 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateApplicationLayerAutomaticResponseRequestRequestTypeDef = TypedDict(
-    "UpdateApplicationLayerAutomaticResponseRequestRequestTypeDef",
-    {
-        "ResourceArn": str,
-        "Action": "ResponseActionTypeDef",
-    },
-)
-
-UpdateEmergencyContactSettingsRequestRequestTypeDef = TypedDict(
-    "UpdateEmergencyContactSettingsRequestRequestTypeDef",
-    {
-        "EmergencyContactList": Sequence["EmergencyContactTypeDef"],
-    },
-    total=False,
-)
-
 _RequiredUpdateProtectionGroupRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateProtectionGroupRequestRequestTypeDef",
     {
@@ -844,3 +433,438 @@ UpdateSubscriptionRequestRequestTypeDef = TypedDict(
     },
     total=False,
 )
+
+ApplicationLayerAutomaticResponseConfigurationTypeDef = TypedDict(
+    "ApplicationLayerAutomaticResponseConfigurationTypeDef",
+    {
+        "Status": ApplicationLayerAutomaticResponseStatusType,
+        "Action": ResponseActionTypeDef,
+    },
+)
+
+EnableApplicationLayerAutomaticResponseRequestRequestTypeDef = TypedDict(
+    "EnableApplicationLayerAutomaticResponseRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Action": ResponseActionTypeDef,
+    },
+)
+
+UpdateApplicationLayerAutomaticResponseRequestRequestTypeDef = TypedDict(
+    "UpdateApplicationLayerAutomaticResponseRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Action": ResponseActionTypeDef,
+    },
+)
+
+AssociateProactiveEngagementDetailsRequestRequestTypeDef = TypedDict(
+    "AssociateProactiveEngagementDetailsRequestRequestTypeDef",
+    {
+        "EmergencyContactList": Sequence[EmergencyContactTypeDef],
+    },
+)
+
+UpdateEmergencyContactSettingsRequestRequestTypeDef = TypedDict(
+    "UpdateEmergencyContactSettingsRequestRequestTypeDef",
+    {
+        "EmergencyContactList": Sequence[EmergencyContactTypeDef],
+    },
+    total=False,
+)
+
+_RequiredSummarizedAttackVectorTypeDef = TypedDict(
+    "_RequiredSummarizedAttackVectorTypeDef",
+    {
+        "VectorType": str,
+    },
+)
+_OptionalSummarizedAttackVectorTypeDef = TypedDict(
+    "_OptionalSummarizedAttackVectorTypeDef",
+    {
+        "VectorCounters": List[SummarizedCounterTypeDef],
+    },
+    total=False,
+)
+
+
+class SummarizedAttackVectorTypeDef(
+    _RequiredSummarizedAttackVectorTypeDef, _OptionalSummarizedAttackVectorTypeDef
+):
+    pass
+
+
+AttackPropertyTypeDef = TypedDict(
+    "AttackPropertyTypeDef",
+    {
+        "AttackLayer": AttackLayerType,
+        "AttackPropertyIdentifier": AttackPropertyIdentifierType,
+        "TopContributors": List[ContributorTypeDef],
+        "Unit": UnitType,
+        "Total": int,
+    },
+    total=False,
+)
+
+AttackSummaryTypeDef = TypedDict(
+    "AttackSummaryTypeDef",
+    {
+        "AttackId": str,
+        "ResourceArn": str,
+        "StartTime": datetime,
+        "EndTime": datetime,
+        "AttackVectors": List[AttackVectorDescriptionTypeDef],
+    },
+    total=False,
+)
+
+AttackVolumeTypeDef = TypedDict(
+    "AttackVolumeTypeDef",
+    {
+        "BitsPerSecond": AttackVolumeStatisticsTypeDef,
+        "PacketsPerSecond": AttackVolumeStatisticsTypeDef,
+        "RequestsPerSecond": AttackVolumeStatisticsTypeDef,
+    },
+    total=False,
+)
+
+_RequiredCreateProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProtectionGroupRequestRequestTypeDef",
+    {
+        "ProtectionGroupId": str,
+        "Aggregation": ProtectionGroupAggregationType,
+        "Pattern": ProtectionGroupPatternType,
+    },
+)
+_OptionalCreateProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProtectionGroupRequestRequestTypeDef",
+    {
+        "ResourceType": ProtectedResourceTypeType,
+        "Members": Sequence[str],
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateProtectionGroupRequestRequestTypeDef(
+    _RequiredCreateProtectionGroupRequestRequestTypeDef,
+    _OptionalCreateProtectionGroupRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredCreateProtectionRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProtectionRequestRequestTypeDef",
+    {
+        "Name": str,
+        "ResourceArn": str,
+    },
+)
+_OptionalCreateProtectionRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProtectionRequestRequestTypeDef",
+    {
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateProtectionRequestRequestTypeDef(
+    _RequiredCreateProtectionRequestRequestTypeDef, _OptionalCreateProtectionRequestRequestTypeDef
+):
+    pass
+
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
+
+CreateProtectionResponseTypeDef = TypedDict(
+    "CreateProtectionResponseTypeDef",
+    {
+        "ProtectionId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeDRTAccessResponseTypeDef = TypedDict(
+    "DescribeDRTAccessResponseTypeDef",
+    {
+        "RoleArn": str,
+        "LogBucketList": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeEmergencyContactSettingsResponseTypeDef = TypedDict(
+    "DescribeEmergencyContactSettingsResponseTypeDef",
+    {
+        "EmergencyContactList": List[EmergencyContactTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetSubscriptionStateResponseTypeDef = TypedDict(
+    "GetSubscriptionStateResponseTypeDef",
+    {
+        "SubscriptionState": SubscriptionStateType,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListResourcesInProtectionGroupResponseTypeDef = TypedDict(
+    "ListResourcesInProtectionGroupResponseTypeDef",
+    {
+        "ResourceArns": List[str],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListAttacksRequestRequestTypeDef = TypedDict(
+    "ListAttacksRequestRequestTypeDef",
+    {
+        "ResourceArns": Sequence[str],
+        "StartTime": TimeRangeTypeDef,
+        "EndTime": TimeRangeTypeDef,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+DescribeProtectionGroupResponseTypeDef = TypedDict(
+    "DescribeProtectionGroupResponseTypeDef",
+    {
+        "ProtectionGroup": ProtectionGroupTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListProtectionGroupsResponseTypeDef = TypedDict(
+    "ListProtectionGroupsResponseTypeDef",
+    {
+        "ProtectionGroups": List[ProtectionGroupTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListProtectionsRequestRequestTypeDef = TypedDict(
+    "ListProtectionsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "InclusionFilters": InclusionProtectionFiltersTypeDef,
+    },
+    total=False,
+)
+
+ListProtectionGroupsRequestRequestTypeDef = TypedDict(
+    "ListProtectionGroupsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "InclusionFilters": InclusionProtectionGroupFiltersTypeDef,
+    },
+    total=False,
+)
+
+ProtectionLimitsTypeDef = TypedDict(
+    "ProtectionLimitsTypeDef",
+    {
+        "ProtectedResourceTypeLimits": List[LimitTypeDef],
+    },
+)
+
+ListAttacksRequestListAttacksPaginateTypeDef = TypedDict(
+    "ListAttacksRequestListAttacksPaginateTypeDef",
+    {
+        "ResourceArns": Sequence[str],
+        "StartTime": TimeRangeTypeDef,
+        "EndTime": TimeRangeTypeDef,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListProtectionsRequestListProtectionsPaginateTypeDef = TypedDict(
+    "ListProtectionsRequestListProtectionsPaginateTypeDef",
+    {
+        "InclusionFilters": InclusionProtectionFiltersTypeDef,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ProtectionGroupPatternTypeLimitsTypeDef = TypedDict(
+    "ProtectionGroupPatternTypeLimitsTypeDef",
+    {
+        "ArbitraryPatternLimits": ProtectionGroupArbitraryPatternLimitsTypeDef,
+    },
+)
+
+ProtectionTypeDef = TypedDict(
+    "ProtectionTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "ResourceArn": str,
+        "HealthCheckIds": List[str],
+        "ProtectionArn": str,
+        "ApplicationLayerAutomaticResponseConfiguration": ApplicationLayerAutomaticResponseConfigurationTypeDef,
+    },
+    total=False,
+)
+
+SubResourceSummaryTypeDef = TypedDict(
+    "SubResourceSummaryTypeDef",
+    {
+        "Type": SubResourceTypeType,
+        "Id": str,
+        "AttackVectors": List[SummarizedAttackVectorTypeDef],
+        "Counters": List[SummarizedCounterTypeDef],
+    },
+    total=False,
+)
+
+ListAttacksResponseTypeDef = TypedDict(
+    "ListAttacksResponseTypeDef",
+    {
+        "AttackSummaries": List[AttackSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredAttackStatisticsDataItemTypeDef = TypedDict(
+    "_RequiredAttackStatisticsDataItemTypeDef",
+    {
+        "AttackCount": int,
+    },
+)
+_OptionalAttackStatisticsDataItemTypeDef = TypedDict(
+    "_OptionalAttackStatisticsDataItemTypeDef",
+    {
+        "AttackVolume": AttackVolumeTypeDef,
+    },
+    total=False,
+)
+
+
+class AttackStatisticsDataItemTypeDef(
+    _RequiredAttackStatisticsDataItemTypeDef, _OptionalAttackStatisticsDataItemTypeDef
+):
+    pass
+
+
+ProtectionGroupLimitsTypeDef = TypedDict(
+    "ProtectionGroupLimitsTypeDef",
+    {
+        "MaxProtectionGroups": int,
+        "PatternTypeLimits": ProtectionGroupPatternTypeLimitsTypeDef,
+    },
+)
+
+DescribeProtectionResponseTypeDef = TypedDict(
+    "DescribeProtectionResponseTypeDef",
+    {
+        "Protection": ProtectionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListProtectionsResponseTypeDef = TypedDict(
+    "ListProtectionsResponseTypeDef",
+    {
+        "Protections": List[ProtectionTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+AttackDetailTypeDef = TypedDict(
+    "AttackDetailTypeDef",
+    {
+        "AttackId": str,
+        "ResourceArn": str,
+        "SubResources": List[SubResourceSummaryTypeDef],
+        "StartTime": datetime,
+        "EndTime": datetime,
+        "AttackCounters": List[SummarizedCounterTypeDef],
+        "AttackProperties": List[AttackPropertyTypeDef],
+        "Mitigations": List[MitigationTypeDef],
+    },
+    total=False,
+)
+
+DescribeAttackStatisticsResponseTypeDef = TypedDict(
+    "DescribeAttackStatisticsResponseTypeDef",
+    {
+        "TimeRange": TimeRangeTypeDef,
+        "DataItems": List[AttackStatisticsDataItemTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+SubscriptionLimitsTypeDef = TypedDict(
+    "SubscriptionLimitsTypeDef",
+    {
+        "ProtectionLimits": ProtectionLimitsTypeDef,
+        "ProtectionGroupLimits": ProtectionGroupLimitsTypeDef,
+    },
+)
+
+DescribeAttackResponseTypeDef = TypedDict(
+    "DescribeAttackResponseTypeDef",
+    {
+        "Attack": AttackDetailTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredSubscriptionTypeDef = TypedDict(
+    "_RequiredSubscriptionTypeDef",
+    {
+        "SubscriptionLimits": SubscriptionLimitsTypeDef,
+    },
+)
+_OptionalSubscriptionTypeDef = TypedDict(
+    "_OptionalSubscriptionTypeDef",
+    {
+        "StartTime": datetime,
+        "EndTime": datetime,
+        "TimeCommitmentInSeconds": int,
+        "AutoRenew": AutoRenewType,
+        "Limits": List[LimitTypeDef],
+        "ProactiveEngagementStatus": ProactiveEngagementStatusType,
+        "SubscriptionArn": str,
+    },
+    total=False,
+)
+
+
+class SubscriptionTypeDef(_RequiredSubscriptionTypeDef, _OptionalSubscriptionTypeDef):
+    pass
+
+
+DescribeSubscriptionResponseTypeDef = TypedDict(
+    "DescribeSubscriptionResponseTypeDef",
+    {
+        "Subscription": SubscriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
